[][src]Struct ip2proxy::Row

pub struct Row {
    pub proxy_type: Option<String>,
    pub country_short: Option<String>,
    pub country_long: Option<String>,
    pub region: Option<String>,
    pub city: Option<String>,
    pub isp: Option<String>,
    pub domain: Option<String>,
    pub usage_type: Option<String>,
    pub asn: Option<String>,
    pub as_name: Option<String>,
    pub last_seen: Option<String>,
}

Database record for an IP address.

Use Database::query() to obtain this from a database.

By convention, - is used for fields where the column is supported but the cell does not have a value.

Fields

proxy_type: Option<String>

Type of proxy, if any.

Proxy typeDescription
VPNAnonymizing VPN service
TORTor exit node
DCHData center, hosting provider, CDN
PUBPublic proxy
WEBWeb based proxy
SESSearch engine spider
country_short: Option<String>

ISO 3166 country code like US.

country_long: Option<String>

ISO 3166 country name like United States of America.

region: Option<String>

Region or state name like California.

city: Option<String>

City name like Los Angeles.

isp: Option<String>

Internet service provider or company name, like APNIC and CloudFlare DNS Resolver Project.

domain: Option<String>

Domain name associated with the IP address, if any, like cloudflare.com.

usage_type: Option<String>

Usage type classification.

Usage typeDescription
COMCommercial
ORGOrganization
GOVGovernment
MILMilitary
EDUUniversity, college, school
LIBLibrary
CDNContent Delivery Network
ISPFixed Line ISP
MOBMobile ISP
DCHData center, hosting provider, transit
SESSearch engine spider
RSVReserved
asn: Option<String>

Autonomous System Number (ASN), like 13335.

as_name: Option<String>

Autonomous System (AS) name, like CLOUDFLARENET.

last_seen: Option<String>

Number of days since the proxy was last seen.

Methods

impl Row[src]

pub fn is_proxy(&self) -> Option<bool>[src]

Checks if the row represents a known proxy of any kind.