pub struct Columns(/* private fields */);Expand description
Set of supported or selected columns.
Example
use ip2proxy::Columns;
assert_eq!(Columns::PX2, Columns::PROXY_TYPE | Columns::COUNTRY_SHORT | Columns::COUNTRY_LONG);Implementations
Sourceimpl Columns
impl Columns
Sourcepub const PROXY_TYPE: Self
pub const PROXY_TYPE: Self
See Row::proxy_type.
Sourcepub const COUNTRY_SHORT: Self
pub const COUNTRY_SHORT: Self
See Row::country_short.
Sourcepub const COUNTRY_LONG: Self
pub const COUNTRY_LONG: Self
See Row::country_long.
Sourcepub const REGION: Self
pub const REGION: Self
See Row::region.
Sourcepub const DOMAIN: Self
pub const DOMAIN: Self
See Row::domain.
Sourcepub const USAGE_TYPE: Self
pub const USAGE_TYPE: Self
See Row::usage_type.
Sourcepub const AS_NAME: Self
pub const AS_NAME: Self
See Row::as_name.
Sourcepub const LAST_SEEN: Self
pub const LAST_SEEN: Self
See Row::last_seen.
Sourcepub const THREAT: Self
pub const THREAT: Self
See Row::threat.
Sourcepub const PROVIDER: Self
pub const PROVIDER: Self
See Row::provider.
Sourcepub const IS_PROXY: Self
pub const IS_PROXY: Self
See Row::is_proxy().
Sourcepub const PX5: Self
pub const PX5: Self
Alias for columns of PX5: IP-ProxyType-Country-Region-City-ISP-Domain Database.
Sourcepub const PX6: Self
pub const PX6: Self
Alias for columns of PX6: IP-ProxyType-Country-Region-City-ISP-Domain-UsageType Database.
Sourcepub const PX7: Self
pub const PX7: Self
Alias for columns of PX7: IP-ProxyType-Country-Region-City-ISP-Domain-UsageType-ASN Database.
Sourcepub const PX8: Self
pub const PX8: Self
Alias for columns of PX8: IP-ProxyType-Country-Region-City-ISP-Domain-UsageType-ASN-LastSeen Database.
Sourcepub const PX9: Self
pub const PX9: Self
Alias for columns of PX9: IP-ProxyType-Country-Region-City-ISP-Domain-UsageType-ASN-LastSeen-Threat Database.
Sourceimpl Columns
impl Columns
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<Self>
pub const fn from_bits(bits: u32) -> Option<Self>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> Self
pub const fn from_bits_truncate(bits: u32) -> Self
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> Self
pub const fn from_bits_retain(bits: u32) -> Self
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<Self>
pub fn from_name(name: &str) -> Option<Self>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: Self) -> bool
pub const fn intersects(&self, other: Self) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: Self) -> bool
pub const fn contains(&self, other: Self) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn remove(&mut self, other: Self)
pub fn remove(&mut self, other: Self)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: Self)
pub fn toggle(&mut self, other: Self)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: Self, value: bool)
pub fn set(&mut self, other: Self, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: Self) -> Self
pub const fn intersection(self, other: Self) -> Self
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: Self) -> Self
pub const fn union(self, other: Self) -> Self
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: Self) -> Self
pub const fn difference(self, other: Self) -> Self
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: Self) -> Self
pub const fn symmetric_difference(self, other: Self) -> Self
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> Self
pub const fn complement(self) -> Self
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl Columns
impl Columns
Sourcepub const fn iter(&self) -> Iter<Columns>
pub const fn iter(&self) -> Iter<Columns>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<Columns>
pub const fn iter_names(&self) -> IterNames<Columns>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.