[−][src]Struct ip2proxy::Row
Database record for an IP address.
Use Database::query() to obtain this
from a database.
By convention, - is used for fields where the column is supported but
the cell does not have a value.
Fields
proxy_type: Option<String>Type of proxy, if any.
| Proxy type | Description |
|---|---|
VPN | Anonymizing VPN service |
TOR | Tor exit node |
DCH | Data center, hosting provider, CDN |
PUB | Public proxy |
WEB | Web based proxy |
SES | Search engine spider |
country_short: Option<String>ISO 3166 country code like US.
country_long: Option<String>ISO 3166 country name like United States of America.
region: Option<String>Region or state name like California.
city: Option<String>City name like Los Angeles.
isp: Option<String>Internet service provider or company name, like
APNIC and CloudFlare DNS Resolver Project.
domain: Option<String>Domain name associated with the IP address, if any,
like cloudflare.com.
usage_type: Option<String>Usage type classification.
| Usage type | Description |
|---|---|
COM | Commercial |
ORG | Organization |
GOV | Government |
MIL | Military |
EDU | University, college, school |
LIB | Library |
CDN | Content Delivery Network |
ISP | Fixed Line ISP |
MOB | Mobile ISP |
DCH | Data center, hosting provider, transit |
SES | Search engine spider |
RSV | Reserved |
asn: Option<String>Autonomous System Number (ASN), like 13335.
as_name: Option<String>Autonomous System (AS) name, like CLOUDFLARENET.
last_seen: Option<String>Number of days since the proxy was last seen.
Methods
impl Row[src]